Modular Symbols
===============

.. toctree::
   :maxdepth: 1

   sage/modular/modsym/modsym

   sage/modular/modsym/space
   sage/modular/modsym/ambient
   sage/modular/modsym/subspace

   sage/modular/modsym/element
   sage/modular/modsym/modular_symbols
   sage/modular/modsym/manin_symbol
   sage/modular/modsym/manin_symbol_list

   sage/modular/modsym/boundary

   sage/modular/modsym/heilbronn

   sage/modular/modsym/p1list
   sage/modular/modsym/g1list
   sage/modular/modsym/ghlist

   sage/modular/modsym/relation_matrix

   sage/modular/modsym/p1list_nf

   sage/modular/modsym/apply
   sage/modular/modsym/hecke_operator
   sage/modular/modsym/relation_matrix_pyx


Overconvergent modular symbols
----------------------------------

.. toctree::
   :maxdepth: 1

   sage/modular/pollack_stevens/space
   sage/modular/pollack_stevens/distributions
   sage/modular/pollack_stevens/fund_domain
   sage/modular/pollack_stevens/padic_lseries
   sage/modular/pollack_stevens/manin_map
   sage/modular/pollack_stevens/modsym

   sage/modular/btquotients/btquotient
   sage/modular/btquotients/pautomorphicform

.. include:: ../footer.txt
